@@ -6,7 +6,7 @@
 @Description :
 """
 import math
-
+from typing import Union
 from django.db.models import Max
 from django.db import transaction
 
@@ -42,7 +42,7 @@ def get_departments(organization_id: int, department_name: str = None) -> dict:
         # 查询到包含搜索关键字的部门
         departments = Department.objects.filter(
             organization_id=organization_id,
-            name__contains=department_name,
+            name__contains=department_name.strip(),
             is_deleted=False
         )
         items = list()
@@ -277,20 +277,30 @@ def add_department_user_map(organization_id: int, department_id: int, user_ids:
 
 
 # def get_department_user(organization_id: int, department_id: int, page: int, size: int):
-def get_department_user(organization_id: int, department_ids: list):
+def get_department_user(organization_id: int, department_id: Union[int, list]):
     """
     通过部门获取用户
     :param organization_id: 组织id
-    :param department_ids: 部门id
+    :param department_id: 部门id
     :param page: 页码
     :param size: 每页数量
     :return:
     """
-    user_ids = DepartmentUserMap.objects.filter(
-        department__organization_id=organization_id,
-        department__is_deleted=False,
-        department_id__in=department_ids
-    ).order_by("-id").values_list("user_id", flat=True)
+    if (isinstance(department_id, str) and department_id.isdigit()) or isinstance(department_id, int):
+        user_ids = DepartmentUserMap.objects.filter(
+            department__organization_id=organization_id,
+            department__is_deleted=False,
+            department_id=department_id
+        ).order_by("-id").values_list("user_id", flat=True)
+
+    elif isinstance(department_id, list):
+        user_ids = DepartmentUserMap.objects.filter(
+            department__organization_id=organization_id,
+            department__is_deleted=False,
+            department_id__in=department_id
+        ).order_by("-id").values_list("user_id", flat=True)
+    else:
+        return Resp(code=ServerErrorCode, msg='department_id type error')
     return Resp(data=list(user_ids))
     # total = user_ids.count()
     # max_page = math.ceil(total / size)
